@@ -1,13 +1,16 @@
 from typing import Optional
 
 from peek_plugin_base.PluginCommonEntryHookABC import PluginCommonEntryHookABC
-from peek_plugin_base.agent.PeekAgentPlatformHookABC import PeekAgentPlatformHookABC
+from peek_plugin_base.agent.PeekAgentPlatformHookABC import \
+    PeekAgentPlatformHookABC
 
 
 class PluginAgentEntryHookABC(PluginCommonEntryHookABC):
 
-    def __init__(self, pluginName: str, pluginRootDir: str, platform: PeekAgentPlatformHookABC):
-        PluginCommonEntryHookABC.__init__(self, pluginName=pluginName, pluginRootDir=pluginRootDir)
+    def __init__(self, pluginName: str, pluginRootDir: str,
+                 platform: PeekAgentPlatformHookABC):
+        PluginCommonEntryHookABC.__init__(self, pluginName=pluginName,
+                                          pluginRootDir=pluginRootDir)
         self._platform = platform
 
     @property
